==> bdnavs-0.0.4.tar.gz: README.md <==
# bdnavs

BDNavs give you awesome bottomnavbar. it is animated navbar.

## Install

1. Depend on it
Add this to your package's pubspec.yaml file:
```
dependencies:
  bdnavs: ^0.0.3
```

2. Install it
You can install packages from the command line:

with Flutter:
```
$ flutter pub get
```
Alternatively, your editor might support flutter pub get. Check the docs for your editor to learn more.

3. Import it
Now in your Dart code, you can use:
```
import 'package:bdnavs/bdnavs.dart';
```

## MIT License

Copyright (c) 2020 salimmurshed12@gmail.com

Name: Salim Murshed
Country: Bangladesh
Email: salimmurshed12@gmail.com



## Getting Started

Use the below code on your app body.

```
NavBs4Down(
      isDown:false,
      index:5,
      iconColors: Colors.blue,
      iconDisableColors: Colors.blue,
      iconBackColors: Colors.red,
      navBackColors: Colors.green,
      icons:<IconData> [
        Icons.home,
        Icons.search,
        Icons.airplanemode_active,
        Icons.favorite, 
        Icons.add
      ],//
      app: [
        Home(),
        Home1(),
        Home(),
        Home1(),
        Home(),
      ],
  )
```

## Property

 Property               |          Use              |        Type
 -----------------------|---------------------------|-----------------------
 isDown                 |   true for down wave      |        (bool)
 isDown                 |   false for upper wave    |        (bool)
 index                  |   for 4 or 5 tabs         |        (int)
 iconDisableColors      |   use Colors. or Color()  |        (Color)
 iconColors             |   use Colors. or Color()  |        (Color)
 iconBackColors         |   use Colors. or Color()  |        (Color)
 navBackColors          |   use Colors. or Color()  |        (Color)
 icons                  |   for 4 or 5 icon         |        (IconData)
 app                    |   for 4 or 5 class        |        (int)
 
 
 ## Demo
      <img src="https://i.ibb.co/WH6M2PG/Screenshot-21.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/59k2sYj/Screenshot-20-1.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/6mMgX4L/Screenshot-22.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/kxPDXjJ/Screenshot-21-1.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/YcGL8LV/Screenshot-23.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/27dmRKK/Screenshot-22-1.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/LkqBSHH/Screenshot-20.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/LSprh3w/Screenshot-23-1.png" alt="How example looks" width="300" height="540">

==> bdnavs-0.0.5.tar.gz: README.md <==
# bdnavs

BDNavs give you awesome bottomnavbar. it is animated navbar.

## Install

1. Depend on it
Add this to your package's pubspec.yaml file:
```
dependencies:
  bdnavs: ^0.0.5
```

2. Install it
You can install packages from the command line:

with Flutter:
```
$ flutter pub get
```
Alternatively, your editor might support flutter pub get. Check the docs for your editor to learn more.

3. Import it
Now in your Dart code, you can use:
```
import 'package:bdnavs/bdnavs.dart';
```

## MIT License

**Copyright (c) 2020 salimmurshed12@gmail.com**

**Name:** Salim Murshed

**Country:** Bangladesh

**Email:** salimmurshed12@gmail.com



## Getting Started

Use the below code on your app body.

```
NavBs4Down(
      isDown:false,
      index:5,
      iconColors: Colors.blue,
      iconDisableColors: Colors.blue,
      iconBackColors: Colors.red,
      navBackColors: Colors.green,
      icons:<IconData> [
        Icons.home,
        Icons.search,
        Icons.airplanemode_active,
        Icons.favorite, 
        Icons.add
      ],//
      app: [
        Home(),
        Home1(),
        Home(),
        Home1(),
        Home(),
      ],
  )
```

## Property

 Property               |          Use              |        Type
 -----------------------|---------------------------|-----------------------
 isDown                 |   true for down wave      |        (bool)
 isDown                 |   false for upper wave    |        (bool)
 index                  |   for 4 or 5 tabs         |        (int)
 iconDisableColors      |   use Colors. or Color()  |        (Color)
 iconColors             |   use Colors. or Color()  |        (Color)
 iconBackColors         |   use Colors. or Color()  |        (Color)
 navBackColors          |   use Colors. or Color()  |        (Color)
 icons                  |   for 4 or 5 icon         |        (IconData)
 app                    |   for 4 or 5 class        |        (int)
 
 
 ## Demo
      <img src="https://i.ibb.co/WH6M2PG/Screenshot-21.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/59k2sYj/Screenshot-20-1.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/6mMgX4L/Screenshot-22.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/kxPDXjJ/Screenshot-21-1.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/YcGL8LV/Screenshot-23.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/27dmRKK/Screenshot-22-1.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/LkqBSHH/Screenshot-20.png" alt="How example looks" width="300" height="540">
  <img src="https://i.ibb.co/LSprh3w/Screenshot-23-1.png" alt="How example looks" width="300" height="540">
